@@ -4,17 +4,10 @@
 static char sun_map_sccsid[] = "@(#)yaccpar	1.9 (Berkeley) 02/21/93";
 #else
 #if defined(__NetBSD__) && defined(__IDSTRING)
-__IDSTRING(sun_map_rcsid, "$NetBSD: skeleton.c,v 1.23 2002/01/31 21:01:15 tv Exp $");
+__IDSTRING(sun_map_rcsid, "$NetBSD: skeleton.c,v 1.25 2003/08/07 11:17:54 agc Exp $");
 #endif /* __NetBSD__ && __IDSTRING */
 #endif /* 0 */
 #endif /* lint */
-#ifndef __P
-#ifdef __STDC__
-#define __P(x) x
-#else
-#define __P(x) ()
-#endif
-#endif
 #define YYBYACC 1
 #define YYMAJOR 1
 #define YYMINOR 9
@@ -26,7 +19,7 @@ __IDSTRING(sun_map_rcsid, "$NetBSD: skeleton.c,v 1.23 2002/01/31 21:01:15 tv Exp
 #define YYPREFIX "sun_map_"
 #line 2 "sun_map_parse.y"
 /*
- * Copyright (c) 1997-2005 Erez Zadok
+ * Copyright (c) 1997-2006 Erez Zadok
  * Copyright (c) 2005 Daniel P. Ottavio
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
@@ -110,7 +103,7 @@ static struct sun_list *get_sun_entry_list();
 typedef union {
   char strval[2048];
 } YYSTYPE;
-#line 114 "sun_map_parse.c"
+#line 107 "sun_map_parse.c"
 #define NEWLINE 257
 #define COMMENT 258
 #define WSPACE 259
@@ -286,7 +279,7 @@ short *sun_map_ss;
 short *sun_map_sslim;
 YYSTYPE *sun_map_vs;
 int sun_map_stacksize;
-int sun_map_parse __P((void));
+int sun_map_parse(void);
 #line 408 "sun_map_parse.y"
 
 /*
@@ -377,10 +370,10 @@ get_sun_opt_list(void)
   }
   return sun_opt_list;
 }
-#line 381 "sun_map_parse.c"
+#line 374 "sun_map_parse.c"
 /* allocate initial stack or double stack size, up to YYMAXDEPTH */
-static int sun_map_growstack __P((void));
-static int sun_map_growstack __P((void))
+static int sun_map_growstack(void);
+static int sun_map_growstack(void)
 {
     int newsize, i;
     short *newss;
@@ -411,7 +404,7 @@ static int sun_map_growstack __P((void))
 #define YYACCEPT goto sun_map_accept
 #define YYERROR goto sun_map_errlab
 int
-sun_map_parse __P((void))
+sun_map_parse(void)
 {
     int sun_map_m, sun_map_n, sun_map_state;
 #if YYDEBUG
@@ -840,7 +833,7 @@ case 28:
   }
 }
 break;
-#line 844 "sun_map_parse.c"
+#line 837 "sun_map_parse.c"
     }
     sun_map_ssp -= sun_map_m;
     sun_map_state = *sun_map_ssp;
