@@ -1,24 +1,24 @@
 
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_TARNAME "am-utils"
-#define PACKAGE_VERSION "6.1-rc4"
-#define PACKAGE_STRING "am-utils 6.1-rc4"
-#define PACKAGE_BUGREPORT "am-utils@am-utils.org"
+#define PACKAGE_VERSION "6.2a2"
+#define PACKAGE_STRING "am-utils 6.2a2"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "netbsd2.0"
+#define HOST_OS "netbsd2.0.2"
 #define HOST_OS_NAME "netbsd"
-#define HOST_OS_VERSION "2.0"
+#define HOST_OS_VERSION "2.0.2"
 #define HOST_ARCH "i386"
 #define DISTRO_NAME "none"
 #define HOST_NAME "a-netbsd20.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Mon May 16 14:44:14 EDT 2005"
+#define CONFIG_DATE "Thu May 11 11:28:19 EDT 2006"
 #define PACKAGE_NAME "am-utils"
-#define PACKAGE_VERSION "6.1-rc4"
-#define PACKAGE_BUGREPORT "am-utils@am-utils.org"
+#define PACKAGE_VERSION "6.2a2"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.1-rc4"
+#define VERSION "6.2a2"
 #define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -31,11 +31,13 @@
 #define HAVE_STDINT_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION "2.0"
+#ifdef __cplusplus
+#include <stdlib.h>
+#endif
+#define HOST_HEADER_VERSION "2.0.2"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_LIBRT 1
-#define HAVE_ALLOCA 1
 #define HAVE_UNISTD_H 1
 #define HAVE_FORK 1
 #define HAVE_VFORK 1
@@ -61,9 +63,6 @@
 #define HAVE_GETMNTINFO 1
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
-#define HAVE_HES_INIT 1
-#define HAVE_HESIOD_INIT 1
-#define HAVE_HESIOD_TO_BIND 1
 #define HAVE_HSTRERROR 1
 #define HAVE_MADVISE 1
 #define HAVE_MEMCMP 1
@@ -85,11 +84,13 @@
 #define HAVE_SIGNAL 1
 #define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
-#define HAVE_STRCHR 1
+#define HAVE_STATFS 1
 #define HAVE_STRCASECMP 1
+#define HAVE_STRCHR 1
 #define HAVE_STRCSPN 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCAT 1
 #define HAVE_STRLCPY 1
 #define HAVE_STRSPN 1
 #define HAVE_STRSTR 1
@@ -102,10 +103,14 @@
 #define HAVE_VSNPRINTF 1
 #define HAVE_WAIT3 1
 #define HAVE_WAITPID 1
+#define HAVE_HES_INIT 1
+#define HAVE_HESIOD_INIT 1
+#define HAVE_HESIOD_TO_BIND 1
 #define HAVE_CLNT_SPERRNO 1
 #define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCAT 1
 #define HAVE_STRLCPY 1
 #define HAVE_STRSTR 1
 #define HAVE_UALARM 1
@@ -205,7 +210,6 @@
 #define HAVE_FCNTL_H 1
 #define HAVE_IFADDRS_H 1
 #define HAVE_GRP_H 1
-#define HAVE_HESIOD_H 1
 #define HAVE_LIBGEN_H 1
 #define HAVE_LIMITS_H 1
 #define HAVE_MALLOC_H 1
@@ -228,6 +232,8 @@
 #define HAVE_TCPD_H 1
 #define HAVE_TIME_H 1
 #define HAVE_UNISTD_H 1
+#define HAVE_HESIOD_H 1
+#define NEW_DBM_H "ndbm.h"
 #define TIME_WITH_SYS_TIME 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_netbsd1_4.h"
 #define HAVE_STRUCT_NFS_ARGS 1
@@ -250,6 +256,7 @@
 #define ufs_args_t struct ufs_args
 #define XDRPROC_T_TYPE xdrproc_t
 #define voidp void *
+#define HAVE_C99_VARARGS_MACROS 1
 #define HAVE_EXTERN_SYS_ERRLIST 1
 #define HAVE_EXTERN_OPTARG 1
 #define HAVE_EXTERN_CLNT_SPCREATEERROR 1
@@ -266,8 +273,10 @@
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
 #define HAVE_EXTERN_SETITIMER 1
+#define HAVE_EXTERN_SLEEP 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
+#define HAVE_EXTERN_STRLCAT 1
 #define HAVE_EXTERN_STRLCPY 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
@@ -289,6 +298,7 @@
 #define HAVE_PCFS_ARGS_T_UID 1
 #define HAVE_UFS_ARGS_T_FSPEC 1
 #define HAVE_STRUCT_STATFS_F_FSTYPENAME 1
+#define HAVE_NFS_ARGS_T_ADDRLEN 1
 #define HAVE_NFS_ARGS_T_FHSIZE 1
 #define HAVE_NFS_ARGS_T_PROTO 1
 #define HAVE_NFS_ARGS_T_SOTYPE 1
@@ -297,8 +307,11 @@
 #define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_STRUCT_SOCKADDR_SA_LEN 1
 #define HAVE_MAP_FILE 1
+#define HAVE_MAP_SUN 1
 #define HAVE_MAP_EXEC 1
 #define HAVE_MAP_HESIOD 1
+#define HAVE_DBM_OPEN 1
+#define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_PASSWD 1
 #define HAVE_MAP_UNION 1
@@ -334,15 +347,18 @@
 #define MOUNT_TYPE_UNIONFS MOUNT_UNION
 #define MOUNT_TYPE_UMAPFS MOUNT_UMAP
 #define MNTTAB_TYPE_NFS "nfs"
-#define MNTTAB_TYPE_NFS3 "nfs3"
-#define MNTTAB_TYPE_UFS "ufs"
-#define MNTTAB_TYPE_CDFS "cdfs"
-#define MNTTAB_TYPE_PCFS "pcfs"
+#define MNTTAB_TYPE_NFS3 "nfs"
+#define MNTTAB_TYPE_UFS "ffs"
+#define MNTTAB_TYPE_CDFS "cd9660"
+#define MNTTAB_TYPE_PCFS "msdos"
 #define MNTTAB_TYPE_MFS "mfs"
-#define MNTTAB_TYPE_NULLFS "nullfs"
-#define MNTTAB_TYPE_UNIONFS "unionfs"
-#define MNTTAB_TYPE_UMAPFS "umapfs"
+#define MNTTAB_TYPE_LFS "lfs"
+#define MNTTAB_TYPE_AFS "afs"
+#define MNTTAB_TYPE_NULLFS "null"
+#define MNTTAB_TYPE_UNIONFS "union"
+#define MNTTAB_TYPE_UMAPFS "umap"
 #define MNT2_GEN_OPT_ASYNC 0x40
+#define MNT2_GEN_OPT_FORCE 0x80000
 #define MNT2_GEN_OPT_IGNORE 0x100000
 #define MNT2_GEN_OPT_NODEV 0x10
 #define MNT2_GEN_OPT_NOEXEC 0x4
@@ -372,4 +388,7 @@
 #define MNT2_CDFS_OPT_EXTATT 0x4
 #define MNT2_CDFS_OPT_GENS 0x2
 #define MNT2_CDFS_OPT_NORRIP 0x1
+#define MNT2_PCFS_OPT_LONGNAME 0x2
+#define MNT2_PCFS_OPT_NOWIN95 0x4
+#define MNT2_PCFS_OPT_SHORTNAME 0x1
 #define HIDE_MOUNT_TYPE "nfs"
